@@ -3,7 +3,7 @@ package Bundle::Thread;
 use strict;
 use warnings;
 
-our $VERSION = '1.21';
+our $VERSION = '1.22';
 $VERSION = eval $VERSION;
 
 1;
@@ -20,17 +20,17 @@ Bundle::Thread - A bundle of modules for supporting threads in Perl
 
 =head1 CONTENTS
 
-Test::Simple 1.001014           - Used for module testing
+Test::Simple 1.302059           - Used for module testing
 
-Scalar::Util 1.45               - Used by several of the other modules below
+Scalar::Util 1.47               - Used by several of the other modules below
 
-threads 2.07                    - Support for threads
+threads 2.12                    - Support for threads
 
-threads::shared 1.51            - Support for sharing objects between threads
+threads::shared 1.54            - Support for sharing objects between threads
 
-Thread::Semaphore 2.12          - Thread-safe semaphores
+Thread::Semaphore 2.13          - Thread-safe semaphores
 
-Thread::Queue 3.09              - Thread-safe queues
+Thread::Queue 3.11              - Thread-safe queues
 
 Thread::Suspend 1.22            - Suspend and resume operations for threads
 
@@ -40,6 +40,14 @@ Thread::Cancel 1.13             - Cancel (i.e., kill) threads
 
 This bundle includes modules used to test and support threads in Perl.
 
+=head1 SEE ALSO
+
+Bundle::Thread on MetaCPAN:
+L<https://metacpan.org/release/Bundle-Thread>
+
+Code repository:
+L<https://github.com/jdhedden/Bundle-Thread>
+
 =head1 AUTHOR
 
 Jerry D. Hedden, S<E<lt>jdhedden AT cpan DOT orgE<gt>>
